'use server';
import 'server-only';
import { createClient } from '@/utils/supabase/server';

export const getImageUrl = async (
  bucket: string,
  path: string,
): Promise<string> => {
  try {
    const supabase = await createClient();

    // Download the image as a blob
    const { data, error } = await supabase.storage.from(bucket).download(path);

    if (error) {
      console.error('Error downloading image:', error);
      throw new Error(`Failed to download image: ${error.message}`);
    }

    if (!data) {
      throw new Error('No data received from storage');
    }

    // Convert blob to base64 string on the server
    const arrayBuffer = await data.arrayBuffer();
    const buffer = Buffer.from(arrayBuffer);
    const base64 = buffer.toString('base64');

    // Determine MIME type from file extension or default to octet-stream
    let mimeType = 'application/octet-stream';
    if (path.endsWith('.png')) mimeType = 'image/png';
    else if (path.endsWith('.jpg') || path.endsWith('.jpeg'))
      mimeType = 'image/jpeg';
    else if (path.endsWith('.gif')) mimeType = 'image/gif';
    else if (path.endsWith('.svg')) mimeType = 'image/svg+xml';
    else if (path.endsWith('.webp')) mimeType = 'image/webp';

    // Return as data URL
    return `data:${mimeType};base64,${base64}`;
  } catch (error) {
    console.error(
      'Error processing image:',
      error instanceof Error ? error.message : String(error),
    );
    throw new Error('Failed to process image');
  }
};
